==> identity-apps-1.2.150-source-release.zip: identity-apps-1.2.150/modules/react-components/src/components/index.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

export * from "./accordion";
export * from "./alert";
export * from "./analytics";
export * from "./avatar";
export * from "./banner";
export * from "./brand";
export * from "./button";
export * from "./card";
export * from "./code-editor";
export * from "./danger-zone";
export * from "./error";
export * from "./footer";
export * from "./grid";
export * from "./header";
export * from "./help-panel";
export * from "./icon";
export * from "./input";
export * from "./label";
export * from "./language-switcher";
export * from "./list";
export * from "./loader";
export * from "./message";
export * from "./modal";
export * from "./page-header";
export * from "./pagination";
export * from "./placeholder";
export * from "./renderer";
export * from "./route";
export * from "./section";
export * from "./side-panel";
export * from "./step";
export * from "./tab";
export * from "./table";
export * from "./typography";
export * from "./theme";
export * from "./transfer";
export * from "./redux-forms";

==> identity-apps-1.6.378-source-release.zip: identity-apps-1.6.378/modules/react-components/src/components/index.ts <==
/**
 * Copyright (c) 2020, WSO2 LLC. (https://www.wso2.com). All Rights Reserved.
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export * from "./accordion";
export * from "./alert";
export * from "./analytics";
export * from "./avatar";
export * from "./banner";
export * from "./brand";
export * from "./button";
export * from "./card";
export * from "./code-editor";
export * from "./containers";
export * from "./danger-zone";
export * from "./documentation";
export * from "./dropdown";
export * from "./error";
export * from "./footer";
export * from "./forms";
export * from "./file-picker";
export * from "./grid";
export * from "./header";
export * from "./help-panel";
export * from "./icon";
export * from "./input";
export * from "./label";
export * from "./language-switcher";
export * from "./links";
export * from "./list";
export * from "./loader";
export * from "./media";
export * from "./message";
export * from "./modal";
export * from "./page-header";
export * from "./pagination";
export * from "./pickers";
export * from "./placeholder";
export * from "./popup";
export * from "./renderer";
export * from "./route";
export * from "./section";
export * from "./side-panel";
export * from "./step";
export * from "./sticky-bar";
export * from "./switcher";
export * from "./tab";
export * from "./table";
export * from "./typography";
export * from "./transfer";
export * from "./redux-forms";
export * from "./validation";
